<h1 align="center">
   <!-- es7s/core -->
   <a href="##"><img align="left" src="https://s3.eu-north-1.amazonaws.com/dp2.dl/readme/es7s/commons/logo.png" width="96" height="96"></a>
   <a href="##"><img src="https://s3.eu-north-1.amazonaws.com/dp2.dl/readme/es7s/commons/label.png" width="200" height="60"></a>
</h1>
<div align="right">
 <a href="##"><img src="https://img.shields.io/badge/python-3.10-3776AB?logo=python&logoColor=white&labelColor=333333"></a>
  <a href="https://pypi.org/project/es7s.commons/"><img alt="PyPI" src="https://img.shields.io/pypi/v/es7s.commons"></a>
  <a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
</div>
<br>
es7s system shared code

## Installation

```shell 
pip install es7s-commons
```

## Changelog

[CHANGES.rst](CHANGES.rst)
